@@ -23,36 +23,24 @@ if TYPE_CHECKING:
 	_: Callable[[str], DeferredTranslation]
 
 
-# add the custom _ as a builtin, it can now be used anywhere in the
-# project to mark strings as translatable with _('translate me')
-DeferredTranslation.install()
-
-# Log various information about hardware before starting the installation. This might assist in troubleshooting
-debug(f"Hardware model detected: {SysInfo.sys_vendor()} {SysInfo.product_name()}; UEFI mode: {SysInfo.has_uefi()}")
-debug(f"Processor model detected: {SysInfo.cpu_model()}")
-debug(f"Memory statistics: {SysInfo.mem_available()} available out of {SysInfo.mem_total()} total installed")
-debug(f"Virtualization detected: {SysInfo.virtualization()}; is VM: {SysInfo.is_vm()}")
-debug(f"Graphics devices detected: {SysInfo._graphics_devices().keys()}")
-
-# For support reasons, we'll log the disk layout pre installation to match against post-installation layout
-debug(f"Disk states before installing:\n{disk_layouts()}")
-
-
-if 'sphinx' not in sys.modules and 'pylint' not in sys.modules:
-	if '--help' in sys.argv or '-h' in sys.argv:
-		arch_config_handler.print_help()
-		exit(0)
-	if os.getuid() != 0:
-		print(_("Archinstall requires root privileges to run. See --help for more."))
-		exit(1)
-
-
 # @archinstall.plugin decorator hook to programmatically add
 # plugins in runtime. Useful in profiles_bck and other things.
 def plugin(f, *args, **kwargs) -> None:  # type: ignore[no-untyped-def]
 	plugins[f.__name__] = f
 
 
+def _log_sys_info() -> None:
+	# Log various information about hardware before starting the installation. This might assist in troubleshooting
+	debug(f"Hardware model detected: {SysInfo.sys_vendor()} {SysInfo.product_name()}; UEFI mode: {SysInfo.has_uefi()}")
+	debug(f"Processor model detected: {SysInfo.cpu_model()}")
+	debug(f"Memory statistics: {SysInfo.mem_available()} available out of {SysInfo.mem_total()} total installed")
+	debug(f"Virtualization detected: {SysInfo.virtualization()}; is VM: {SysInfo.is_vm()}")
+	debug(f"Graphics devices detected: {SysInfo._graphics_devices().keys()}")
+
+	# For support reasons, we'll log the disk layout pre installation to match against post-installation layout
+	debug(f"Disk states before installing:\n{disk_layouts()}")
+
+
 def _fetch_arch_db() -> None:
 	info("Fetching Arch Linux package database...")
 	try:
@@ -77,12 +65,22 @@ def _check_new_version() -> None:
 		time.sleep(3)
 
 
-def main() -> None:
+def main() -> int:
 	"""
 	This can either be run as the compiled and installed application: python setup.py install
 	OR straight as a module: python -m archinstall
 	In any case we will be attempting to load the provided script to be run from the scripts/ folder
 	"""
+	if '--help' in sys.argv or '-h' in sys.argv:
+		arch_config_handler.print_help()
+		return 0
+
+	if os.getuid() != 0:
+		print(_("Archinstall requires root privileges to run. See --help for more."))
+		return 1
+
+	_log_sys_info()
+
 	if not arch_config_handler.args.offline:
 		_fetch_arch_db()
 
@@ -95,12 +93,15 @@ def main() -> None:
 	# by loading the module we'll automatically run the script
 	importlib.import_module(mod_name)
 
+	return 0
+
 
 def run_as_a_module() -> None:
+	rc = 0
 	exc = None
 
 	try:
-		main()
+		rc = main()
 	except Exception as e:
 		exc = e
 	finally:
@@ -118,7 +119,9 @@ def run_as_a_module() -> None:
 			)
 
 			warn(text)
-			exit(1)
+			rc = 1
+
+		exit(rc)
 
 
 __all__ = [
