@@ -1,8 +1,6 @@
 from typing import TYPE_CHECKING, override
 
-import archinstall
 from archinstall.default_profiles.profile import Profile, ProfileType
-from archinstall.lib.models import User
 
 if TYPE_CHECKING:
 	from archinstall.lib.installer import Installer
@@ -27,9 +25,6 @@ class DockerProfile(Profile):
 
 	@override
 	def post_install(self, install_session: 'Installer') -> None:
-		users: User | list[User] = archinstall.arguments.get('!users', [])
-		if not isinstance(users, list):
-			users = [users]
-
-		for user in users:
+		from archinstall.lib.args import arch_config_handler
+		for user in arch_config_handler.config.users:
 			install_session.arch_chroot(f'usermod -a -G docker {user.username}')
